import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = 'https://gist.githubusercontent.com/Tejamod/f6296fe79c46e2bf76eb7052367e9f0b/raw/3943601b65a329d602eaf92d4d363e002072b501/gamesales.csv'
 
const parseRow = (d) => {
  d.Year = +d.Year;
  d.Global_Sales = +d.Global_Sales;
  d.NA_Sales = +d.NA_Sales;
  d.EU_Sales = +d.EU_Sales;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Global_Sales)
    .yValue((d) => d.Year)
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 120,
    })
    .radius(5);

  svg.call(plot);

  const columns = [
    'Year',
    'Global_Sales',
    'NA_Sales',
    'EU_Sales'

  ];
  
  
  
  svg.append('text')
          .attr('class', 'axis-label')
          .attr('x', -innerHeight / 2)
          .attr('y', 38)
          .attr('fill', 'black')
          .style("font", "25px times")
          .style('text-anchor', 'Center')
          .attr('transform', `rotate(-90)`)
          .text('Year');
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
  
 
};
main();



